==> apache-pulsar-2.8.3-src.tar.gz: apache-pulsar-2.8.3-src/site2/website/data/users.js <==
module.exports = [
    {
        name: 'Kingsoft Cloud',
        url: 'https://www.ksyun.com/',
        logo: 'https://fe.ksyun.com/header/images/pc/logo.png?a048d39f',
        logo_white: true
    },
    {
        name: 'Narvar',
        url: 'https://corp.narvar.com/',
        logo: 'https://assets-global.website-files.com/5d278e4646ba9e55d6c67475/5d49ce69c03a64b2d8466816_Logo%20-%20Colored.svg',
    },
    {
        name: 'Giggso',
        url: 'https://giggso.com/',
        logo: 'https://www.giggso.com/wp-content/uploads/2019/11/logo-2.png',
        logo_white: true
    },
    {
        name: 'STICorp',
        url: 'https://www.sticorp.com.br/',
        logo: 'https://www.sticorp.com.br/wp-content/uploads/2015/09/logo-horizontal.png',
    },
    {
        name: 'Verizon Media',
        url: 'https://www.verizonmedia.com/',
        logo: 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/09/Verizon_Media_2019_logo.svg/1200px-Verizon_Media_2019_logo.svg.png',
        featured: 1
    },
    {
        name: 'Yahoo! JAPAN',
        url: 'https://www.yahoo.co.jp/',
        logo: 'https://s.yimg.jp/images/top/sp2/cmn/logo-170307.png',
        featured: 2
    },
    {
        name: 'Zhaopin',
        url: 'https://www.zhaopin.com/',
        logo: 'https://fecdn5.zhaopin.cn/www/assets/zhaopin.4659478df1ec9a2e6ed76997a64884f6.png'
    },
    {
        name: 'Onde',
        url: 'https://onde.app/',
        logo: 'https://pbs.twimg.com/profile_images/1142024893229346818/JlCmThRZ_200x200.png',
    },
    {
        name: 'Overstock',
        url: 'https://www.overstock.com/',
        logo: 'https://ak1.ostkcdn.com/img/mxc/OSTK_MAIN_LOGO_20181127KCH.jpg'
    },
    {
        name: 'Ndustrial.io',
        url: 'https://www.ndustrial.io/',
        logo: 'https://images.squarespace-cdn.com/content/v1/56df41f2f699bb94c7a2c6fc/1552657060081-WX86GJXHX7UK81RGE6YU/ke17ZwdGBToddI8pDm48kKCofG1A85AnHnyK5g0bGkJZw-zPPgdn4jUwVcJE1ZvWQUxwkmyExglNqGp0IvTJZUJFbgE-7XRK3dMEBRBhUpzRPjxD400fzchYtVcY_asIzZyz67rHxPkx39rBmDbrxrXjNbFEDrPRRKbjQDhrWWQ/ndustrial.png'
    },
    {
        name: 'Nutanix',
        url: 'https://www.nutanix.com/',
        logo: 'https://www.zuora.com/wp-content/uploads/2017/05/nutanix.png',
        featured: 4
    },
    {
        name: 'The Hut Group',
        url: 'https://www.thg.com',
        logo: 'https://1000logos.net/wp-content/uploads/2020/09/THG-Logo-1024x640.png'
    },
    {
        name: 'Turtlequeue',
        url: 'https://turtlequeue.com',
        logo: 'https://turtlequeue.com/logo_black.png'
    },
    {
        name: 'ProxyClick',
        url: 'https://www.proxyclick.com/',
        logo: 'https://www.proxyclick.com/hubfs/assets/images/logo-positive.svg'
    },
    {
        name: 'Toast',
        url: 'https://toasttab.com',
        logo: 'https://cdn2.hubspot.net/hubfs/412971/toast-restaurant-pos.png'
    },
    {
        name: 'Quantel AI',
        url: 'http://quantel.ai/',
        logo: 'https://quantel.ai/wp-content/uploads/2019/09/Quantel-AI-Black-Font-Trans-1024x1024.png'
    },
    {
        name: 'Splunk',
        url: 'https://splunk.com/',
        logo: 'https://www.splunk.com/content/dam/splunk-blogs/images/2017/02/splunk-logo.png',
        featured: 5
    },
    {
        name: 'Stream Native',
        url: 'https://streamnative.io/',
        logo: 'https://streamnative.io/static/images/streamnative-logo-white-bakground.png',
    },
    {
        name: 'EMQ',
        url: 'https://www.emqx.io/',
        logo: 'https://www.emqx.io/static/img/logo.svg',
        logo_white: true
    },
    {
        name: 'Tencent',
        url: 'https://www.tencent.com',
        logo: 'http://pluspng.com/img-png/tencent-png-tencent-logo-logotype-emblem-2-7537.png',
        featured: 3
    },
    {
        name: 'Comcast',
        url: 'https://corporate.comcast.com/',
        logo: 'https://corporate.comcast.com/resources/corporate/assets/images/svg/logo-desktop.svg'
    },
    {
        name: 'China Mobile',
        url: 'https://www.chinamobileltd.com/',
        logo: 'https://www.chinamobileltd.com/en/images/global/logo.svg'
    },
    {
        name: 'VipKid',
        url: 'https://t.vipkid.com.cn/',
        logo: 'https://s.vipkidstatic.com/fe-static/teacher/mkt-pc/img/e74f189.svg'
    },
    {
        name: 'Vivy',
        url: 'https://www.vivy.com/de/startseite/',
        logo: 'https://www.vivy.com/fileadmin/vivy-startpage/vivy_logo.svg'
    },
    {
        name: 'IoTium',
        url: 'https://www.iotium.io/',
        logo: 'https://www.iotium.io/site/wp-content/uploads/2018/04/IoTium-logo.jpg'
    },
    {
        name: 'One Click Retail',
        url: 'https://oneclickretail.com/',
        logo: 'https://www.ascentialedge.com/themes/contrib/custom/images/edge-by-ascential.svg',
        logo_white: true
    },
    {
        name: 'Tuya',
        url: 'https://en.tuya.com/',
        logo: 'https://static1.tuyaus.com/static/portal_intl/img/e25eefa.png'
    },
    {
        name: 'China Telecom',
        url: 'https://www.chinatelecom-h.com/',
        logo: 'https://www.chinatelecom-h.com/en/images/global/logo.png'
    },
    {
        name: 'Kafkaesque',
        url: 'https://kafkaesque.io/',
        logo: 'https://kafkaesque.io/wp-content/uploads/2019/04/color_logo_with_background.svg'
    },
    {
        name: 'OKCoin',
        url: 'https://www.okcoin.com/',
        logo: 'https://static.bafang.com/cdn/assets/imgs/206/BC3E3ADD7E55C085.png',
    },
    {
        name: 'BestPay',
        url: 'https://www.bestpay.com.cn/',
        logo: 'https://www.bestpay.com.cn/global/oig/images/logo.png'
    },
    {
        name: '360',
        url: 'https://www.360.cn/',
        logo: 'http://p2.ssl.qhimg.com/t01d91636862957f76e.png'
    },
    {
        name: 'Lakala',
        url: 'http://www.lakala.com/',
        logo: 'http://www.lakala.com/templets/default/image/temp/logo.png'
    },
    {
        name: 'Huya',
        url: 'https://www.huya.com/',
        logo: 'https://a.msstatic.com/huya/main/img/logo2.png',
        logo_white: true
    },
    {
        name: 'CTWing',
        url: 'https://www.ctwing.cn/',
        logo: 'https://www.ctwing.cn/static/img/logo.168f8b7.svg'
    },
    {
        name: 'Globalegrow E-Commerce',
        url: 'https://www.globalegrow.com/',
        logo: 'https://static.globalegrow.com/dist/images/domeimg/ch/logo.jpg'
    },
    {
        name: 'YunZhiHuLian',
        url: 'https://www.weihudashi.com',
        logo: 'https://www.weihudashi.com/image/header-logo.png'
    },
    {
        name: 'XiaoDuoAI',
        url: 'https://www.xiaoduoai.com/',
        logo: 'https://cdn.xiaoduoai.com/official-site/dist/assets/img/indexPage/xiaoduo_logo_en_white.843927.png',
        logo_white: true
    },
    {
        name: 'Shihong',
        url: 'https://shihong.net.cn',
        logo: 'https://shihong.net.cn/website/static/src/img/shihong1.png'
    },
    {
        name: 'CleverCloud',
        url: 'https://www.clever-cloud.com/en/',
        logo: 'https://www.clever-cloud.com/images/brand-assets/logos/v2/logo_on_white.svg'
    },
    {
        name: 'OVHcloud',
        url: 'https://www.ovhcloud.com/',
        logo: 'https://www.ovh.com/world/images/logo/ovhLogoColor.svg'
    },
    {
        name: 'BrandsEye',
        url: 'https://www.brandseye.com/',
        logo: 'https://www.brandseye.com/theme-images/brandseye-logo-v2.png'
    },
    {
        name: 'Max Kelsen',
        url: 'https://maxkelsen.com/',
        logo: 'https://maxkelsen.com/imgs/logo/Max-Kelsen-logo-black.png'
    },
    {
        name: 'HSL Developer Community of Helsinki Regional Transport Authority',
        url: 'https://dev.hsl.fi/',
        logo: 'https://pbs.twimg.com/profile_images/2507371771/9toyr6r5ngcozfwg42zv_400x400.png'
    },
    // {
    //     name: 'Ottoo',
    //     url: 'https://ottoo.com',
    //     logo: 'https://ottoo.com/assets/images/ottoo-logo.svg'
    // },
    {
        name: 'MercadoLibre',
        url: 'https://www.mercadolibre.com/',
        logo: 'https://d1.awsstatic.com/case-studies/LATAM/mercadolibre.1d9d3766bb06e60948f1c5ce8851ce0eac63b349.png'
    },
    {
        name: 'BIGO',
        url: 'https://www.bigo.sg/',
        logo: 'https://static-web.bigolive.tv/as/bigo-static/official_website/pc/img/about/logo-blue-big.png',
    },
    {
        name: 'Keytop',
        url: 'https://www.ikeytop.com/',
        logo: 'https://static.wixstatic.com/media/ecbdea_434ae22f85ed4e93ba3fdc39c7141c3f~mv2.png/v1/fill/w_424,h_116,al_c,usm_0.66_1.00_0.01/Keytop_logo.png',
    },
    {
        name: 'Zhihu',
        url: 'https://www.zhihu.com/',
        logo: 'https://pic4.zhimg.com/80/v2-a47051e92cf74930bedd7469978e6c08_hd.png',
    },
    {
        name: 'Newland',
        url: 'http://www.nlsoft.com.cn/',
        logo: 'http://www.nlsoft.com.cn/images/common/logo.png',
    },
    {
        name: 'PalFish',
        url: 'https://www.ipalfish.com/',
        logo: 'https://s04.cdn.ipalfish.com/kid/img/logo.ad4731cb.png',
    },
    {
        name: 'Dada Group',
        url: 'https://about.imdada.cn',
        logo: 'https://fe.imdada.cn/alaskan/static/logo_color-aaed10c6738b703ad2b54c17f4c3f114.png',
    },
    {
        name: 'Huawei Cloud',
        url: 'https://www.huaweicloud.com',
        logo: 'https://res.hc-cdn.com/cnpm-common-resource/2.0.2/base/header/components/images/logo.png',
    },
    {
        name: 'Su Ning',
        url: 'https://www.suning.com',
        logo: 'https://image1.suning.cn/uimg/cms/img/159642507148437980.png',
    },
    {
        name: 'Pingan Securites',
        url: 'https://stock.pingan.com',
        logo: 'https://stock.pingan.com/static/uploads/softdowm/2018-10-9/upload_c9ac4929e293f5109623b541740618ba.png',
    },
    {
        name: 'Ge Tui',
        url: 'https://www.getui.com',
        logo: 'https://gt-static.getui.com/getui_pc/client/img/e33ecd9.svg',
        logo_white: true
    },
    {
        name: 'DataStax',
        url: 'https://datastax.com',
        logo: 'https://www.datastax.com/sites/default/files/inline-images/datastax-logotype-negative.png',
        logo_white: false
    },
    {
        name: 'KAISA',
        url: 'https://www.kaisafin.com',
        logo: 'https://www.kaisafin.com/images/logo.svg',
    },
    {
        name: 'Bairong.Inc',
        url: 'http://www.brgroup.com',
        logo: 'http://www.brgroup.com/_nuxt/img/logo.d2a976e.png',
          logo_white: true
    },
    {
        name: 'Itcast.cn',
        url: 'http://www.itcast.cn',
        logo: 'http://www.itcast.cn/2018czgw/images/logo2.png',
    },
    {
        name: 'Appen',
        url: 'https://www.appen.com.cn/',
        logo: 'https://resources.appen.com/wp-content/uploads/2020/03/no-tagline.svg',
    },
    {
        name: 'Pandio',
        url: 'https://pandio.com',
        logo: 'https://pandio-public-assets.s3-us-west-2.amazonaws.com/pandio_225-05.png',
    },
    {
        name: 'Deposit-Solutions',
        url: 'https://www.deposit-solutions.com/',
        logo: 'https://www.deposit-solutions.com/wp-content/uploads/2017/05/ds_logo_light_horiz.png'
    },
    {
        name: 'Macrometa',
        url: 'https://macrometa.com',
        logo: 'https://uploads-ssl.webflow.com/5fa9e94bc848ae335afdd627/602ae50ae801b44f15185683_logo-moc-blue.png',
    },
    {
        name: 'Softtech',
        url: 'https://softtech.com.tr/en/homepage/',
        logo: 'https://softtech.com.tr/wp-content/uploads/2017/12/SOFTTECH-LOGO.png',
    }
].sort((a, b) => (a.name > b.name) ? 1 : -1);

==> apache-pulsar-2.9.5-src.tar.gz: apache-pulsar-2.9.5-src/site2/website/data/users.js <==
module.exports = [
    {
        name: 'Kingsoft Cloud',
        url: 'https://www.ksyun.com/',
        logo: 'https://fe.ksyun.com/header/images/pc/logo.png?a048d39f',
        logo_white: true
    },
    {
        name: 'Narvar',
        url: 'https://corp.narvar.com/',
        logo: 'https://assets-global.website-files.com/5d278e4646ba9e55d6c67475/5d49ce69c03a64b2d8466816_Logo%20-%20Colored.svg',
    },
    {
        name: 'Giggso',
        url: 'https://giggso.com/',
        logo: 'https://www.giggso.com/wp-content/uploads/2021/06/logo-giggs.png',
    },
    {
        name: 'STICorp',
        url: 'https://www.sticorp.com.br/',
        logo: 'https://sticorp.com.br/wp-content/uploads/2021/02/logo-sticorp.png',
    },
    {
        name: 'Verizon Media',
        url: 'https://www.verizonmedia.com/',
        logo: 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/09/Verizon_Media_2019_logo.svg/1200px-Verizon_Media_2019_logo.svg.png',
        featured: 1
    },
    {
        name: 'Yahoo! JAPAN',
        url: 'https://www.yahoo.co.jp/',
        logo: 'https://s.yimg.jp/images/top/sp2/cmn/logo-170307.png',
        featured: 2
    },
    {
        name: 'Zhaopin',
        url: 'https://www.zhaopin.com/',
        logo: 'https://fecdn5.zhaopin.cn/www/assets/zhaopin.4659478df1ec9a2e6ed76997a64884f6.png'
    },
    {
        name: 'Onde',
        url: 'https://onde.app/',
        logo: 'https://pbs.twimg.com/profile_images/1142024893229346818/JlCmThRZ_200x200.png',
    },
    {
        name: 'Overstock',
        url: 'https://www.overstock.com/',
        logo: 'https://ak1.ostkcdn.com/img/mxc/OSTK_MAIN_LOGO_20181127KCH.jpg'
    },
    {
        name: 'Ndustrial.io',
        url: 'https://www.ndustrial.io/',
        logo: 'https://images.squarespace-cdn.com/content/v1/56df41f2f699bb94c7a2c6fc/1552657060081-WX86GJXHX7UK81RGE6YU/ke17ZwdGBToddI8pDm48kKCofG1A85AnHnyK5g0bGkJZw-zPPgdn4jUwVcJE1ZvWQUxwkmyExglNqGp0IvTJZUJFbgE-7XRK3dMEBRBhUpzRPjxD400fzchYtVcY_asIzZyz67rHxPkx39rBmDbrxrXjNbFEDrPRRKbjQDhrWWQ/ndustrial.png'
    },
    {
        name: 'Nutanix',
        url: 'https://www.nutanix.com/',
        logo: 'https://www.zuora.com/wp-content/uploads/2017/05/nutanix.png',
        featured: 4
    },
    {
        name: 'The Hut Group',
        url: 'https://www.thg.com',
        logo: 'https://1000logos.net/wp-content/uploads/2020/09/THG-Logo-1024x640.png'
    },
    {
        name: 'Turtlequeue',
        url: 'https://turtlequeue.com',
        logo: 'https://turtlequeue.com/logo_black.png'
    },
    {
        name: 'ProxyClick',
        url: 'https://www.proxyclick.com/',
        logo: 'https://www.proxyclick.com/hubfs/assets/images/logo-positive.svg'
    },
    {
        name: 'Toast',
        url: 'https://toasttab.com',
        logo: 'https://cdn2.hubspot.net/hubfs/412971/toast-restaurant-pos.png'
    },
    {
        name: 'Quantel AI',
        url: 'http://quantel.ai/',
        logo: 'https://static.wixstatic.com/media/7c19eb_41a090c255c94d19bc37cca9777c1d90~mv2.jpg/v1/fill/w_314,h_270,al_c,q_80,usm_0.66_1.00_0.01/Quantel-final%20white%20bg.webp'
    },
    {
        name: 'Splunk',
        url: 'https://splunk.com/',
        logo: 'https://www.splunk.com/content/dam/splunk-blogs/images/2017/02/splunk-logo.png',
        featured: 5
    },
    {
        name: 'StreamNative',
        url: 'https://streamnative.io/',
        logo: 'https://streamnative.io/assets/static/sn-logo-vertical-dark.c516648.a34f97839dee38e7499aa0c21d0b2255.png',
    },
    {
        name: 'EMQ',
        url: 'https://www.emqx.io/',
        logo: 'https://www.emqx.io/images/logo.png',
    },
    {
        name: 'Tencent',
        url: 'https://www.tencent.com',
        logo: 'http://pluspng.com/img-png/tencent-png-tencent-logo-logotype-emblem-2-7537.png',
        featured: 3
    },
    {
        name: 'Comcast',
        url: 'https://corporate.comcast.com/',
        logo: 'https://corporate.comcast.com/resources/corporate/assets/images/svg/logo-desktop.svg'
    },
    {
        name: 'China Mobile',
        url: 'https://www.chinamobileltd.com/',
        logo: 'https://www.chinamobileltd.com/en/images/global/logo.svg'
    },
    {
        name: 'VipKid',
        url: 'https://t.vipkid.com.cn/',
        logo: 'https://s.vipkidstatic.com/fe-static/teacher/mkt-pc/img/e74f189.svg'
    },
    {
        name: 'Vivy',
        url: 'https://www.vivy.com/de/startseite/',
        logo: 'https://www.vivy.com/fileadmin/vivy-startpage/vivy_logo.svg'
    },
    {
        name: 'IoTium',
        url: 'https://www.iotium.io/',
        logo: 'https://www.iotium.io/site/wp-content/uploads/2018/04/IoTium-logo.jpg'
    },
    {
        name: 'One Click Retail',
        url: 'https://oneclickretail.com/',
        logo: 'https://www.ascentialedge.com/themes/contrib/custom/images/edge-by-ascential.svg',
        logo_white: true
    },
    {
        name: 'Tuya',
        url: 'https://en.tuya.com/',
        logo: 'https://static1.tuyaus.com/static/portal_intl/img/e25eefa.png'
    },
    {
        name: 'China Telecom',
        url: 'https://www.chinatelecom-h.com/',
        logo: 'https://www.chinatelecom-h.com/en/images/global/logo.png'
    },
    {
        name: 'Kafkaesque',
        url: 'https://kafkaesque.io/',
        logo: 'https://kafkaesque.io/wp-content/uploads/2019/04/color_logo_with_background.svg'
    },
    {
        name: 'OKCoin',
        url: 'https://www.okcoin.com/',
        logo: 'https://i0.wp.com/blog.okcoin.com/wp-content/uploads/2019/08/OKCoin-Logo-Spring2019-250x60px-01.png?fit=251%2C62&ssl=1',
    },
    {
        name: 'BestPay',
        url: 'https://www.bestpay.com.cn/',
        logo: 'https://www.bestpay.com.cn/global/oig/images/logo.png'
    },
    {
        name: '360',
        url: 'https://www.360.cn/',
        logo: 'http://p2.ssl.qhimg.com/t01d91636862957f76e.png'
    },
    {
        name: 'Lakala',
        url: 'http://www.lakala.com/',
        logo: 'http://www.lakala.com/templets/default/image/temp/logo.png'
    },
    {
        name: 'Huya',
        url: 'https://www.huya.com/',
        logo: 'https://a.msstatic.com/huya/main/img/logo2.png',
        logo_white: true
    },
    {
        name: 'CTWing',
        url: 'https://www.ctwing.cn/',
        logo: 'https://www.ctwing.cn/r/cms/www/default/images/public/logo.png'
    },
    {
        name: 'Globalegrow E-Commerce',
        url: 'https://www.globalegrow.com/',
        logo: 'https://static.globalegrow.com/dist/images/domeimg/ch/logo.jpg'
    },
    {
        name: 'YunZhiHuLian',
        url: 'https://www.weihudashi.com',
        logo: 'https://www.weihudashi.com/image/header-logo.png'
    },
    {
        name: 'XiaoDuoAI',
        url: 'https://www.xiaoduoai.com/',
        logo: 'https://cdn.xiaoduoai.com/official-site/dist/assets/img/indexPage/xiaoduo_logo_en_white.843927.png',
        logo_white: true
    },
    {
        name: 'Shihong',
        url: 'https://shihong.net.cn',
        logo: 'https://www.shihong.net.cn/website/static/src/img/shihong1.png'
    },
    {
        name: 'CleverCloud',
        url: 'https://www.clever-cloud.com/en/',
        logo: 'https://www.clever-cloud.com/images/brand-assets/logos/v2/logo_on_white.svg'
    },
    {
        name: 'OVHcloud',
        url: 'https://www.ovhcloud.com/',
        logo: 'https://www.ovh.com/world/images/logo/ovhLogoColor.svg'
    },
    {
        name: 'BrandsEye',
        url: 'https://www.brandseye.com/',
        logo: 'https://www.brandseye.com/theme-images/brandseye-logo-v2.png'
    },
    {
        name: 'Max Kelsen',
        url: 'https://maxkelsen.com/',
        logo: 'https://maxkelsen.com/imgs/logo/Max-Kelsen-logo-black.png'
    },
    {
        name: 'HSL Developer Community of Helsinki Regional Transport Authority',
        url: 'https://dev.hsl.fi/',
        logo: 'https://pbs.twimg.com/profile_images/2507371771/9toyr6r5ngcozfwg42zv_400x400.png'
    },
    // {
    //     name: 'Ottoo',
    //     url: 'https://ottoo.com',
    //     logo: 'https://ottoo.com/assets/images/ottoo-logo.svg'
    // },
    {
        name: 'MercadoLibre',
        url: 'https://www.mercadolibre.com/',
        logo: 'https://d1.awsstatic.com/case-studies/LATAM/mercadolibre.1d9d3766bb06e60948f1c5ce8851ce0eac63b349.png'
    },
    {
        name: 'BIGO',
        url: 'https://www.bigo.sg/',
        logo: 'https://static-web.bigolive.tv/as/bigo-static/official_website/pc/img/about/logo-blue-big.png',
    },
    {
        name: 'Keytop',
        url: 'https://www.ikeytop.com/',
        logo: 'https://static.wixstatic.com/media/ecbdea_434ae22f85ed4e93ba3fdc39c7141c3f~mv2.png/v1/fill/w_424,h_116,al_c,usm_0.66_1.00_0.01/Keytop_logo.png',
    },
    {
        name: 'Zhihu',
        url: 'https://www.zhihu.com/',
        logo: 'https://pic4.zhimg.com/80/v2-a47051e92cf74930bedd7469978e6c08_hd.png',
    },
    {
        name: 'Newland',
        url: 'http://www.nlsoft.com.cn/',
        logo: 'http://www.nlsoft.com.cn/images/common/logo.png',
    },
    {
        name: 'PalFish',
        url: 'https://www.ipalfish.com/',
        logo: 'https://s04.cdn.ipalfish.com/kid/img/logo.ad4731cb.png',
    },
    {
        name: 'Dada Group',
        url: 'https://about.imdada.cn',
        logo: 'https://fe.imdada.cn/alaskan/static/logo_color-aaed10c6738b703ad2b54c17f4c3f114.png',
    },
    {
        name: 'Huawei Cloud',
        url: 'https://www.huaweicloud.com',
        logo: 'https://res.hc-cdn.com/cnpm-common-resource/2.0.2/base/header/components/images/logo.png',
    },
    {
        name: 'Su Ning',
        url: 'https://www.suning.com',
        logo: 'https://image1.suning.cn/uimg/cms/img/159642507148437980.png',
    },
    {
        name: 'Pingan Securites',
        url: 'https://stock.pingan.com',
        logo: 'https://stock.pingan.com/static/uploads/softdowm/2018-10-9/upload_c9ac4929e293f5109623b541740618ba.png',
    },
    {
        name: 'Ge Tui',
        url: 'https://www.getui.com',
        logo: 'https://gt-static.getui.com/getui_pc/client/img/e33ecd9.svg',
        logo_white: true
    },
    {
        name: 'DataStax',
        url: 'https://datastax.com',
        logo: 'https://www.datastax.com/sites/default/files/inline-images/datastax-logotype-negative.png',
        logo_white: false
    },
    {
        name: 'KAISA',
        url: 'https://www.kaisafin.com',
        logo: 'https://www.kaisafin.com/images/logo.svg',
    },
    {
        name: 'Bairong.Inc',
        url: 'http://www.brgroup.com',
        logo: 'http://www.brgroup.com/_nuxt/img/d2a976e.png',
          logo_white: true
    },
    {
        name: 'Itcast.cn',
        url: 'http://www.itcast.cn',
        logo: 'http://www.itcast.cn/2018czgw/images/logo2.png',
    },
    {
        name: 'Appen',
        url: 'https://www.appen.com.cn/',
        logo: 'https://resources.appen.com/wp-content/uploads/2020/03/no-tagline.svg',
    },
    {
        name: 'Pandio',
        url: 'https://pandio.com',
        logo: 'https://pandio-public-assets.s3-us-west-2.amazonaws.com/pandio_225-05.png',
    },
    {
        name: 'Deposit-Solutions',
        url: 'https://www.deposit-solutions.com/',
        logo: 'https://media-exp1.licdn.com/dms/image/C4E0BAQGWAAW9iYFSwA/company-logo_200_200/0/1625219600895?e=1638403200&v=beta&t=iGNhEWlAFQDJOHAScjumctjY5M2eSU4fL4X-9kgpR2M'
    },
    {
        name: 'Macrometa',
        url: 'https://macrometa.com',
        logo: 'https://uploads-ssl.webflow.com/5fa9e94bc848ae335afdd627/602ae50ae801b44f15185683_logo-moc-blue.png',
    },
    {
        name: 'Softtech',
        url: 'https://softtech.com.tr/en/homepage/',
        logo: 'https://softtech.com.tr/wp-content/uploads/2017/12/SOFTTECH-LOGO.png',
    }
].sort((a, b) => (a.name > b.name) ? 1 : -1);
